﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Character : MonoBehaviour {
	public KeyCode key;
	public int playerNumber;
	public ParticleSystem jumpParticles, landParticles;

	private float jumpHeight;
	private bool isAlive = true;
	private Animator anim;
	private Rigidbody rb;
	private bool isGrounded = false;
	private bool upwardsPush = false;
	private Vector3 movement = Vector3.zero;
	private float jumpCharge;

	private void Awake()
	{
		rb = GetComponent<Rigidbody>();
		anim = GetComponentInChildren<Animator>();
	}
	
	void Update ()
	{
		if(isAlive)
		{
			//jump
			if(isGrounded && Input.GetKeyDown(key))
			{
				jumpParticles.Play();
				isGrounded = false;
				anim.SetTrigger("Jump");
				rb.AddForce(Vector3.up * 4f, ForceMode.Impulse);
				jumpCharge = 0f;
				jumpHeight = 0f;
			}
			
			upwardsPush = false;
			if(!isGrounded
				&& Input.GetKey(key)
				&& jumpCharge < .2f)
			{
				jumpCharge += Time.deltaTime;
				upwardsPush = true;
			}
			
			movement = new Vector3(Input.GetAxis("P"+playerNumber+"Horizontal"), 0f, Input.GetAxis("P"+playerNumber+"Vertical"));

			//store the jump peak
			if(!isGrounded)
			{
				jumpHeight = Mathf.Max(transform.position.y, jumpHeight);
			}

			//dead condition
			if(transform.position.y < -5f)
			{
				//dead
				Debug.Log("P" + playerNumber + " died");
				GameManager.Instance.OnPlayerDead(playerNumber);
				isAlive = false;
			}
		}
	}

	public void Respawn()
	{
		isAlive = true;

		Vector2 charPos = Random.insideUnitCircle.normalized * 2.5f + Vector2.one * 3.2f;
		transform.position = new Vector3(charPos.x, .1f, charPos.y);
		rb.velocity = Vector3.zero;
		isGrounded = false;
	}

	private void FixedUpdate()
	{
		if(movement.sqrMagnitude > .1f)
		{
			rb.AddForce(movement * 20f, ForceMode.Force);
		}

		if(upwardsPush)
		{
			rb.AddForce(Vector3.up * 30f, ForceMode.Force);
		}

		rb.velocity = new Vector3(rb.velocity.x * .8f, rb.velocity.y, rb.velocity.z * .8f);
		anim.SetFloat("Speed", movement.sqrMagnitude);
	}

	private void OnCollisionEnter(Collision coll)
	{
		if(isGrounded)
			return;

		if(coll.gameObject.tag == "Ground"
			&& rb.velocity.y <= 0f)
		{
			landParticles.Play();
			isGrounded = true;
			WaveManager.Instance.CreateWave(new Vector2(transform.position.x, transform.position.z) * 10f, this.playerNumber, jumpHeight * .6f);
			anim.SetTrigger("Landed");
		}
	}
}
