﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using DG.Tweening;
using UnityEngine.EventSystems;

public class GameManager : Singleton<GameManager>
{
	public GameStates state = GameStates.TitleScreen;

	public Character[] characters;
	public int winScore = 3;

	private int[] scores;

	private void Awake()
	{
		DOTween.Init();

		scores = new int[2];

		ChangeState(GameStates.TitleScreen);
	}

	private void ChangeState(GameStates newState)
	{
		switch(newState)
		{
			case GameStates.TitleScreen:
				//resetting scores
				scores[0] = 0;
				scores[1] = 0;
				UIManager.Instance.ChangeScore(0, 0);
				UIManager.Instance.ChangeScore(1, 0);

				UIManager.Instance.TransitionToTitle();
				break;

			case GameStates.Gameplay:
				UIManager.Instance.TransitionToGameplay();
				StartCoroutine(DelayedStartGameplay());
				break;

			case GameStates.Endgame:
				//resetting players
				characters[0].gameObject.SetActive(false);
				characters[1].gameObject.SetActive(false);
				UIManager.Instance.TransitionToEndGame();
				break;
		}

		state = newState;
	}

	private IEnumerator DelayedStartGameplay()
	{
		yield return new WaitForSeconds(1f);

		characters[0].gameObject.SetActive(true);
		characters[0].Respawn();
		characters[1].gameObject.SetActive(true);
		characters[1].Respawn();
	}

	public void OnPlayerDead(int playerNumber)
	{
		int otherPlayerNumber = (playerNumber+1)%2;
		scores[otherPlayerNumber]++;
		UIManager.Instance.ChangeScore(otherPlayerNumber, scores[otherPlayerNumber]);

		if(scores[otherPlayerNumber] == winScore)
		{
			ChangeState(GameStates.Endgame);
		}
		else
		{
			StartCoroutine(SpawnPlayer(playerNumber));
		}
	}

	private IEnumerator SpawnPlayer(int playerNumber)
	{
		yield return new WaitForSeconds(1f);

		characters[playerNumber].Respawn();
	}

	public void ChangeRounds(BaseEventData data)
	{
		AxisEventData axisData = data as AxisEventData;

		if(axisData.moveDir == MoveDirection.Left)
		{
			winScore -= 2;
		}
		if(axisData.moveDir == MoveDirection.Right)
		{
			winScore += 2;
		}

		winScore = Mathf.Clamp(winScore, 1, 7);

		UIManager.Instance.DisplayNumberOfRounds(winScore);
	}

	public void BackToTitleScreen()
	{
		ChangeState(GameStates.TitleScreen);
	}

	public void QuitGame()
	{
		Application.Quit();
	}

	public void StartGame()
	{
		ChangeState(GameStates.Gameplay);
	}

	public enum GameStates
	{
		TitleScreen,
		Gameplay,
		Endgame
	}
}
